@@ -18,7 +18,7 @@ if test "${DRONE_TARGET_BRANCH}" = "stable-2.6"; then
     UBUNTU_DISTRIBUTIONS="bionic focal jammy kinetic"
     DEBIAN_DISTRIBUTIONS="buster stretch testing"
 else
-    UBUNTU_DISTRIBUTIONS="jammy kinetic"
+    UBUNTU_DISTRIBUTIONS="jammy kinetic lunar"
     DEBIAN_DISTRIBUTIONS="bullseye testing"
 fi
 
