@@ -420,26 +420,25 @@ void AccountSettings::slotEditCurrentIgnoredFiles()
 
 void AccountSettings::slotOpenMakeFolderDialog()
 {
-    const auto &selected = _ui->_folderList->selectionModel()->currentIndex();
+    const auto selected = _ui->_folderList->selectionModel()->currentIndex();
 
     if (!selected.isValid()) {
         qCWarning(lcAccountSettings) << "Selection model current folder index is not valid.";
         return;
     }
 
-    const auto &classification = _model->classify(selected);
+    const auto classification = _model->classify(selected);
 
     if (classification != FolderStatusModel::SubFolder && classification != FolderStatusModel::RootFolder) {
         return;
     }
 
-    const auto fileName = [this, &selected, &classification] {
+    const auto folder = _model->infoForIndex(selected)->_folder;
+    Q_ASSERT(folder);
+    const auto fileName = [selected, classification, folder, this] {
         QString result;
         if (classification == FolderStatusModel::RootFolder) {
-            const auto alias = _model->data(selected, FolderStatusDelegate::FolderAliasRole).toString();
-            if (const auto folder = FolderMan::instance()->folder(alias)) {
-                result = folder->path();
-            }
+            result = folder->path();
         } else {
             result = _model->data(selected, FolderStatusDelegate::FolderPathRole).toString();
         }
@@ -455,6 +454,14 @@ void AccountSettings::slotOpenMakeFolderDialog()
         const auto folderCreationDialog = new FolderCreationDialog(fileName, this);
         folderCreationDialog->setAttribute(Qt::WA_DeleteOnClose);
         folderCreationDialog->open();
+
+#ifdef Q_OS_MAC
+        // The macOS FolderWatcher cannot detect file and folder changes made by the watching process -- us.
+        // So we need to manually invoke the slot that is called by watched folder changes.
+        connect(folderCreationDialog, &FolderCreationDialog::folderCreated, this, [folder, fileName](const QString &fullFolderPath) {
+            folder->slotWatchedPathChanged(fullFolderPath, Folder::ChangeReason::Other);
+        });
+#endif
     }
 }
 
@@ -513,7 +520,7 @@ void AccountSettings::slotSubfolderContextMenuRequested(const QModelIndex& index
     if (acc->capabilities().clientSideEncryptionAvailable()) {
         // Verify if the folder is empty before attempting to encrypt.
 
-        const auto isEncrypted = info->_isEncrypted;
+        const auto isEncrypted = info->isEncrypted();
         const auto isParentEncrypted = _model->isAnyAncestorEncrypted(index);
 
         if (!isEncrypted && !isParentEncrypted) {
@@ -1514,33 +1521,6 @@ void AccountSettings::refreshSelectiveSyncStatus()
     }
 }
 
-void AccountSettings::slotDeleteAccount()
-{
-    // Deleting the account potentially deletes 'this', so
-    // the QMessageBox should be destroyed before that happens.
-    const auto messageBox = new QMessageBox(QMessageBox::Question,
-                                            tr("Confirm Account Removal"),
-                                            tr("<p>Do you really want to remove the connection to the account <i>%1</i>?</p>"
-                                               "<p><b>Note:</b> This will <b>not</b> delete any files.</p>")
-                                            .arg(_accountState->account()->displayName()),
-                                            QMessageBox::NoButton,
-                                            this);
-    const auto yesButton = messageBox->addButton(tr("Remove connection"), QMessageBox::YesRole);
-    messageBox->addButton(tr("Cancel"), QMessageBox::NoRole);
-    messageBox->setAttribute(Qt::WA_DeleteOnClose);
-    connect(messageBox, &QMessageBox::finished, this, [this, messageBox, yesButton]{
-        if (messageBox->clickedButton() == yesButton) {
-            // Else it might access during destruction. This should be better handled by it having a QSharedPointer
-            _model->setAccountState(nullptr);
-
-            const auto manager = AccountManager::instance();
-            manager->deleteAccount(_accountState);
-            manager->save();
-        }
-    });
-    messageBox->open();
-}
-
 bool AccountSettings::event(QEvent *e)
 {
     if (e->type() == QEvent::Hide || e->type() == QEvent::Show) {
