@@ -75,27 +75,28 @@ namespace {
 
     static const char optionsC[] =
         "Options:\n"
-        "  --help, -h           : show this help screen.\n"
-        "  --version, -v        : show version information.\n"
-        "  -q --quit            : quit the running instance\n"
-        "  --logwindow, -l      : open a window to show log output.\n"
-        "  --logfile <filename> : write log output to file <filename>.\n"
-        "  --logdir <name>      : write each sync log output in a new file\n"
-        "                         in folder <name>.\n"
-        "  --logexpire <hours>  : removes logs older than <hours> hours.\n"
-        "                         (to be used with --logdir)\n"
-        "  --logflush           : flush the log file after every write.\n"
-        "  --logdebug           : also output debug-level messages in the log.\n"
-        "  --confdir <dirname>  : Use the given configuration folder.\n"
-        "  --background         : launch the application in the background.\n"
-        "  --overrideserverurl  : specify a server URL to use for the force override to be used in the account setup wizard.\n"
-        "  --overridelocaldir   : specify a local dir to be used in the account setup wizard.\n"
-        "  --userid             : userId (username as on the server) to pass when creating an account via command-line.\n"
-        "  --apppassword        : appPassword to pass when creating an account via command-line.\n"
-        "  --localdirpath       : (optional) path where to create a local sync folder when creating an account via command-line.\n"
-        "  --isvfsenabled       : whether to set a VFS or non-VFS folder (1 for 'yes' or 0 for 'no') when creating an account via command-line.\n"
-        "  --remotedirpath      : (optional) path to a remote subfolder when creating an account via command-line.\n"
-        "  --serverurl          : a server URL to use when creating an account via command-line.\n";
+        "  --help, -h                 : show this help screen.\n"
+        "  --version, -v              : show version information.\n"
+        "  -q --quit                  : quit the running instance\n"
+        "  --logwindow, -l            : open a window to show log output.\n"
+        "  --logfile <filename>       : write log output to file <filename>.\n"
+        "  --logdir <name>            : write each sync log output in a new file\n"
+        "                               in folder <name>.\n"
+        "  --logexpire <hours>        : removes logs older than <hours> hours.\n"
+        "                               (to be used with --logdir)\n"
+        "  --logflush                 : flush the log file after every write.\n"
+        "  --logdebug                 : also output debug-level messages in the log.\n"
+        "  --confdir <dirname>        : Use the given configuration folder.\n"
+        "  --background               : launch the application in the background.\n"
+        "  --overrideserverurl        : specify a server URL to use for the force override to be used in the account setup wizard.\n"
+        "  --overridelocaldir         : specify a local dir to be used in the account setup wizard.\n"
+        "  --userid                   : userId (username as on the server) to pass when creating an account via command-line.\n"
+        "  --apppassword              : appPassword to pass when creating an account via command-line.\n"
+        "  --localdirpath             : (optional) path where to create a local sync folder when creating an account via command-line.\n"
+        "  --isvfsenabled             : whether to set a VFS or non-VFS folder (1 for 'yes' or 0 for 'no') when creating an account via command-line.\n"
+        "  --remotedirpath            : (optional) path to a remote subfolder when creating an account via command-line.\n"
+        "  --serverurl                : a server URL to use when creating an account via command-line.\n"
+        "  --forcelegacyconfigimport  : forcefully import account configurations from legacy clients (if available).\n";
 
     QString applicationTrPath()
     {
@@ -120,7 +121,7 @@ namespace {
 #ifdef Q_OS_WIN
 class WindowsNativeEventFilter : public QAbstractNativeEventFilter {
 public:
-    bool nativeEventFilter(const QByteArray &eventType, void *message, long *result) {
+    bool nativeEventFilter(const QByteArray &eventType, void *message, long *result) override {
         const auto msg = static_cast<MSG *>(message);
         if(msg->message == WM_SYSCOLORCHANGE || msg->message == WM_SETTINGCHANGE) {
             if (const auto ptr = qobject_cast<QGuiApplication *>(QGuiApplication::instance())) {
@@ -176,7 +177,7 @@ bool Application::configVersionMigration()
             tr("Some settings were configured in %1 versions of this client and "
                "use features that are not available in this version.<br>"
                "<br>"
-               "Continuing will mean <b>%2 these settings</b><br>"
+               "Continuing will mean <b>%2 these settings</b>.<br>"
                "<br>"
                "The current configuration file was already backed up to <i>%3</i>.")
                 .arg((downgrading ? tr("newer", "newer software version") : tr("older", "older software version")),
@@ -187,7 +188,7 @@ bool Application::configVersionMigration()
 
         box.exec();
         if (box.clickedButton() != continueBtn) {
-            QTimer::singleShot(0, qApp, SLOT(quit()));
+            QTimer::singleShot(0, qApp, &QCoreApplication::quit);
             return false;
         }
 
@@ -332,13 +333,25 @@ Application::Application(int &argc, char **argv)
     ConfigFile cfg;
 
     {
+        auto shouldExit = false;
+
         // these config values will always be empty after the first client run
         if (!_overrideServerUrl.isEmpty()) {
-             cfg.setOverrideServerUrl(_overrideServerUrl);
+            cfg.setOverrideServerUrl(_overrideServerUrl);
+            shouldExit = true;
         }
 
         if (!_overrideLocalDir.isEmpty()) {
             cfg.setOverrideLocalDir(_overrideLocalDir);
+            shouldExit = true;
+        }
+
+        if (AccountSetupCommandLineManager::instance()) {
+            cfg.setVfsEnabled(AccountSetupCommandLineManager::instance()->isVfsEnabled());
+        }
+
+        if (shouldExit) {
+            std::exit(0);
         }
     }
 
@@ -365,12 +378,16 @@ Application::Application(int &argc, char **argv)
 
     connect(this, &SharedTools::QtSingleApplication::messageReceived, this, &Application::slotParseMessage);
 
-    if (!AccountManager::instance()->restore(cfg.overrideServerUrl().isEmpty())) {
+    const auto tryMigrate = cfg.overrideServerUrl().isEmpty();
+    auto accountsRestoreResult = AccountManager::AccountsRestoreFailure;
+    if (accountsRestoreResult = AccountManager::instance()->restore(tryMigrate);
+            accountsRestoreResult == AccountManager::AccountsRestoreFailure) {
         // If there is an error reading the account settings, try again
         // after a couple of seconds, if that fails, give up.
         // (non-existence is not an error)
         Utility::sleep(5);
-        if (!AccountManager::instance()->restore(cfg.overrideServerUrl().isEmpty())) {
+        if (accountsRestoreResult = AccountManager::instance()->restore(tryMigrate);
+                accountsRestoreResult == AccountManager::AccountsRestoreFailure) {
             qCCritical(lcApplication) << "Could not read the account settings, quitting";
             QMessageBox::critical(
                 nullptr,
@@ -379,7 +396,7 @@ Application::Application(int &argc, char **argv)
                    "file at %1. Please make sure the file can be accessed by your system account.")
                     .arg(ConfigFile().configFile()),
                 tr("Quit %1").arg(Theme::instance()->appNameGUI()));
-            QTimer::singleShot(0, qApp, SLOT(quit()));
+            QTimer::singleShot(0, qApp, &QCoreApplication::quit);
             return;
         }
     }
@@ -733,8 +750,9 @@ void Application::parseOptions(const QStringList &options)
             } else {
                 showHint("Invalid URL passed to --overridelocaldir");
             }
-        }
-        else {
+        } else if (option == QStringLiteral("--forcelegacyconfigimport")) {
+            AccountManager::instance()->setForceLegacyImport(true);
+        } else {
             QString errorMessage;
             if (!AccountSetupCommandLineManager::instance()->parseCommandlineOption(option, it, errorMessage)) {
                 if (!errorMessage.isEmpty()) {
@@ -765,7 +783,7 @@ static inline void toHtml(QString &t)
 static void displayHelpText(QString t) // No console on Windows.
 {
     toHtml(t);
-    QMessageBox::information(0, Theme::instance()->appNameGUI(), t);
+    QMessageBox::information(nullptr, Theme::instance()->appNameGUI(), t);
 }
 
 #else
