@@ -203,7 +203,8 @@ LinkShare::LinkShare(AccountPtr account,
     const QUrl &url,
     const QDate &expireDate,
     const QString &note,
-    const QString &label)
+    const QString &label,
+    const bool hideDownload)
     : Share(account, id, uidowner, ownerDisplayName, path, Share::TypeLink, isPasswordSet, permissions)
     , _name(name)
     , _token(token)
@@ -211,6 +212,7 @@ LinkShare::LinkShare(AccountPtr account,
     , _expireDate(expireDate)
     , _url(url)
     , _label(label)
+    , _hideDownload(hideDownload)
 {
 }
 
@@ -239,6 +241,11 @@ QString LinkShare::getLabel() const
     return _label;
 }
 
+bool LinkShare::getHideDownload() const
+{
+    return _hideDownload;
+}
+
 void LinkShare::setName(const QString &name)
 {
     createShareJob(&LinkShare::slotNameSet)->setName(getId(), name);
@@ -270,6 +277,11 @@ void LinkShare::setLabel(const QString &label)
     createShareJob(&LinkShare::slotLabelSet)->setLabel(getId(), label);
 }
 
+void LinkShare::setHideDownload(const bool hideDownload)
+{
+    createShareJob(&LinkShare::slotHideDownloadSet)->setHideDownload(getId(), hideDownload);
+}
+
 template <typename LinkShareSlot>
 OcsShareJob *LinkShare::createShareJob(const LinkShareSlot slotFunction) {
     auto *job = new OcsShareJob(_account);
@@ -308,6 +320,16 @@ void LinkShare::slotLabelSet(const QJsonDocument &, const QVariant &label)
     }
 }
 
+void LinkShare::slotHideDownloadSet(const QJsonDocument &jsonDoc, const QVariant &hideDownload)
+{
+    Q_UNUSED(jsonDoc);
+    if (!hideDownload.isValid()) {
+        return;
+    }
+    _hideDownload = hideDownload.toBool();
+    emit hideDownloadSet();
+}
+
 UserGroupShare::UserGroupShare(AccountPtr account,
     const QString &id,
     const QString &owner,
@@ -396,6 +418,14 @@ void ShareManager::createLinkShare(const QString &path,
     job->createLinkShare(path, name, password);
 }
 
+void ShareManager::createSecureFileDropShare(const QString &path, const QString &name, const QString &password)
+{
+    const auto createShareJob = new OcsShareJob(_account);
+    connect(createShareJob, &OcsShareJob::shareJobFinished, this, &ShareManager::slotLinkShareCreated);
+    connect(createShareJob, &OcsJob::ocsError, this, &ShareManager::slotOcsError);
+    createShareJob->createSecureFileDropLinkShare(path, name, password);
+}
+
 void ShareManager::slotLinkShareCreated(const QJsonDocument &reply)
 {
     QString message;
@@ -575,7 +605,8 @@ QSharedPointer<LinkShare> ShareManager::parseLinkShare(const QJsonObject &data)
         url,
         expireDate,
         note,
-        data.value("label").toString()));
+        data.value("label").toString(),
+        data.value("hide_download").toInt() == 1));
 }
 
 SharePtr ShareManager::parseShare(const QJsonObject &data) const
