@@ -15,14 +15,15 @@
 #ifndef ACTIVITYDATA_H
 #define ACTIVITYDATA_H
 
-#include <QtCore>
-#include <QIcon>
-#include <QJsonObject>
-
 #include "syncfileitem.h"
 #include "folder.h"
 #include "account.h"
 
+#include <QtCore>
+#include <QIcon>
+#include <QJsonObject>
+#include <QVariantMap>
+
 namespace OCC {
 /**
  * @brief The ActivityLink class describes actions of an activity
@@ -79,6 +80,52 @@ public:
     QString _filename;
 };
 
+struct RichSubjectParameter {
+    Q_GADGET
+    Q_PROPERTY(QString type MEMBER type)
+    Q_PROPERTY(QString id MEMBER id)
+    Q_PROPERTY(QString name MEMBER name)
+    Q_PROPERTY(QString path MEMBER path)
+    Q_PROPERTY(QUrl link MEMBER link)
+
+public:
+    QString type;    // Required
+    QString id;      // Required
+    QString name;    // Required
+    QString path;    // Required (for files only)
+    QUrl link;    // Optional (files only)
+};
+
+struct TalkNotificationData {
+    Q_GADGET
+    Q_PROPERTY(QString conversationToken MEMBER conversationToken)
+    Q_PROPERTY(QString messageId MEMBER messageId)
+    Q_PROPERTY(QString messageSent MEMBER messageSent)
+    Q_PROPERTY(QString userAvatar MEMBER userAvatar)
+
+public:
+    QString conversationToken;
+    QString messageId;
+    QString messageSent;
+    QString userAvatar;
+
+    [[nodiscard]] bool operator==(const TalkNotificationData &other) const
+    {
+        return conversationToken == other.conversationToken &&
+            messageId == other.messageId &&
+            messageSent == other.messageSent &&
+            userAvatar == other.userAvatar;
+    }
+
+    [[nodiscard]] bool operator!=(const TalkNotificationData &other) const
+    {
+        return conversationToken != other.conversationToken ||
+            messageId != other.messageId ||
+            messageSent != other.messageSent ||
+            userAvatar != other.userAvatar;
+    }
+};
+
 /* ==================================================================== */
 /**
  * @brief Activity Structure
@@ -86,9 +133,13 @@ public:
  *
  * contains all the information describing a single activity.
  */
-
 class Activity
 {
+    Q_GADGET
+    Q_PROPERTY(OCC::Activity::Type type MEMBER _type)
+    Q_PROPERTY(OCC::TalkNotificationData talkNotificationData MEMBER _talkNotificationData)
+    Q_PROPERTY(QVariantMap subjectRichParameters MEMBER _subjectRichParameters)
+
 public:
     using Identifier = QPair<qlonglong, QString>;
 
@@ -102,25 +153,15 @@ public:
         DummyMoreActivitiesAvailableType,
     };
 
+    Q_ENUM(Type)
+
     static Activity fromActivityJson(const QJsonObject &json, const AccountPtr account);
 
     static QString relativeServerFileTypeIconPath(const QMimeType &mimeType);
     static QString localFilePathForActivity(const Activity &activity, const AccountPtr account);
 
-    struct RichSubjectParameter {
-        QString type;    // Required
-        QString id;      // Required
-        QString name;    // Required
-        QString path;    // Required (for files only)
-        QUrl link;    // Optional (files only)
-    };
-
-    struct TalkNotificationData {
-        QString conversationToken;
-        QString messageId;
-        QString messageSent;
-        QString userAvatar;
-    };
+    using RichSubjectParameter = OCC::RichSubjectParameter;
+    using TalkNotificationData = OCC::TalkNotificationData;
 
     Type _type;
     qlonglong _id = 0LL;
@@ -131,7 +172,7 @@ public:
     QString _objectName;
     QString _subject;
     QString _subjectRich;
-    QHash<QString, RichSubjectParameter> _subjectRichParameters;
+    QVariantMap _subjectRichParameters;
     QString _subjectDisplay;
     QString _message;
     QString _folder;
@@ -157,6 +198,7 @@ public:
      * @return
      */
 
+    bool _shouldNotify = true;
 
     [[nodiscard]] Identifier ident() const;
 };
@@ -177,7 +219,9 @@ using ActivityList = QList<Activity>;
 }
 
 Q_DECLARE_METATYPE(OCC::Activity)
+Q_DECLARE_METATYPE(OCC::ActivityList)
 Q_DECLARE_METATYPE(OCC::Activity::Type)
+Q_DECLARE_METATYPE(OCC::Activity::RichSubjectParameter)
 Q_DECLARE_METATYPE(OCC::ActivityLink)
 Q_DECLARE_METATYPE(OCC::PreviewData)
 
