@@ -89,6 +89,8 @@ public:
     /// returns true if the server supports client side encryption
     [[nodiscard]] bool clientSideEncryptionAvailable() const;
 
+    [[nodiscard]] double clientSideEncryptionVersion() const;
+
     /// returns true if the capabilities are loaded already.
     [[nodiscard]] bool isValid() const;
 
@@ -165,6 +167,8 @@ public:
      */
     [[nodiscard]] bool uploadConflictFiles() const;
 
+    [[nodiscard]] bool groupFoldersAvailable() const;
+
     // Direct Editing
     void addDirectEditor(DirectEditor* directEditor);
     DirectEditor* getDirectEditorForMimetype(const QMimeType &mimeType);
