@@ -426,6 +426,11 @@ bool Theme::forceOverrideServerUrl() const
     return _forceOverrideServerUrl;
 }
 
+bool Theme::isVfsEnabled() const
+{
+    return _isVfsEnabled;
+}
+
 bool Theme::startLoginFlowAutomatically() const
 {
     return _startLoginFlowAutomatically;
@@ -568,7 +573,7 @@ QString Theme::aboutDetails() const
               .arg(MIRALL_VERSION_STRING)
               .arg(helpUrl());
 
-    devString += tr("<p>This release was supplied by %1</p>")
+    devString += tr("<p>This release was supplied by %1.</p>")
               .arg(APPLICATION_VENDOR);
 
     devString += gitSHA1();
@@ -971,6 +976,14 @@ void Theme::setForceOverrideServerUrl(bool forceOverride)
     }
 }
 
+void Theme::setVfsEnabled(bool enabled)
+{
+    if (_isVfsEnabled != enabled) {
+        _isVfsEnabled = enabled;
+        emit vfsEnabledChanged();
+    }
+}
+
 void Theme::setStartLoginFlowAutomatically(bool startLoginFlowAuto)
 {
     if (_startLoginFlowAutomatically != startLoginFlowAuto) {
