@@ -214,7 +214,8 @@ class FakePropfindReply : public FakeReply
 public:
     QByteArray payload;
 
-    FakePropfindReply(FileInfo &remoteRootFileInfo, QNetworkAccessManager::Operation op, const QNetworkRequest &request, QObject *parent);
+    explicit FakePropfindReply(FileInfo &remoteRootFileInfo, QNetworkAccessManager::Operation op, const QNetworkRequest &request, QObject *parent);
+    explicit FakePropfindReply(const QByteArray &replyContents, QNetworkAccessManager::Operation op, const QNetworkRequest &request, QObject *parent);
 
     Q_INVOKABLE void respond();
 
@@ -559,7 +560,7 @@ public:
     void execUntilItemCompleted(const QString &relativePath);
 
     bool execUntilFinished() {
-        QSignalSpy spy(_syncEngine.get(), SIGNAL(finished(bool)));
+        QSignalSpy spy(_syncEngine.get(), &OCC::SyncEngine::finished);
         bool ok = spy.wait(3600000);
         Q_ASSERT(ok && "Sync timed out");
         return spy[0][0].toBool();
