@@ -125,7 +125,7 @@ using namespace OCC::Utility;
         _expectedType = "Adler32";
         vali->setChecksumType(_expectedType);
 
-        connect(vali, SIGNAL(done(QByteArray,QByteArray)), SLOT(slotUpValidated(QByteArray,QByteArray)));
+        connect(vali, &ComputeChecksum::done, this, &TestChecksumValidator::slotUpValidated);
 
         auto file = new QFile(_testfile, vali);
         file->open(QIODevice::ReadOnly);
@@ -134,7 +134,7 @@ using namespace OCC::Utility;
         vali->start(_testfile);
 
         QEventLoop loop;
-        connect(vali, SIGNAL(done(QByteArray,QByteArray)), &loop, SLOT(quit()), Qt::QueuedConnection);
+        connect(vali, &ComputeChecksum::done, &loop, &QEventLoop::quit, Qt::QueuedConnection);
         loop.exec();
 
         delete vali;
@@ -146,7 +146,7 @@ using namespace OCC::Utility;
         auto *vali = new ComputeChecksum(this);
         _expectedType = OCC::checkSumMD5C;
         vali->setChecksumType(_expectedType);
-        connect(vali, SIGNAL(done(QByteArray,QByteArray)), this, SLOT(slotUpValidated(QByteArray,QByteArray)));
+        connect(vali, &ComputeChecksum::done, this, &TestChecksumValidator::slotUpValidated);
 
         auto file = new QFile(_testfile, vali);
         file->open(QIODevice::ReadOnly);
@@ -154,7 +154,7 @@ using namespace OCC::Utility;
         vali->start(_testfile);
 
         QEventLoop loop;
-        connect(vali, SIGNAL(done(QByteArray,QByteArray)), &loop, SLOT(quit()), Qt::QueuedConnection);
+        connect(vali, &ComputeChecksum::done, &loop, &QEventLoop::quit, Qt::QueuedConnection);
         loop.exec();
 
         delete vali;
@@ -165,7 +165,7 @@ using namespace OCC::Utility;
         auto *vali = new ComputeChecksum(this);
         _expectedType = OCC::checkSumSHA1C;
         vali->setChecksumType(_expectedType);
-        connect(vali, SIGNAL(done(QByteArray,QByteArray)), this, SLOT(slotUpValidated(QByteArray,QByteArray)));
+        connect(vali, &ComputeChecksum::done, this, &TestChecksumValidator::slotUpValidated);
 
         auto file = new QFile(_testfile, vali);
         file->open(QIODevice::ReadOnly);
@@ -174,7 +174,7 @@ using namespace OCC::Utility;
         vali->start(_testfile);
 
         QEventLoop loop;
-        connect(vali, SIGNAL(done(QByteArray,QByteArray)), &loop, SLOT(quit()), Qt::QueuedConnection);
+        connect(vali, &ComputeChecksum::done, &loop, &QEventLoop::quit, Qt::QueuedConnection);
         loop.exec();
 
         delete vali;
